@@ -1,13 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MungeFile::WithConfigFile;
-BEGIN {
-  $Dist::Zilla::Plugin::MungeFile::WithConfigFile::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.001-1-geb6e2e4
-$Dist::Zilla::Plugin::MungeFile::WithConfigFile::VERSION = '0.002';
+package Dist::Zilla::Plugin::MungeFile::WithConfigFile; # git description: v0.002-31-gb7979e4
 # ABSTRACT: Modify files in the build, with templates and config data from a file
-# vim: set ts=8 sw=4 tw=78 et :
+# KEYWORDS: plugin file content injection modification template configuration file
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.003';
 
 use Moose;
 with (
@@ -28,7 +26,7 @@ has files => (
     lazy => 1,
     default => sub { [] },
     traits => ['Array'],
-    handles => { files => 'elements' },
+    handles => { files => 'sort' },
 );
 
 has configfile => (
@@ -89,7 +87,7 @@ sub munge_file
 {
     my ($self, $file) = @_;
 
-    $self->log_debug('updating contents of ' . $file->name . ' in memory');
+    $self->log_debug([ 'updating contents of %s in memory', $file->name ]);
 
     $file->content(
         $self->fill_in_string(
@@ -112,15 +110,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge FileMunger FileFinder irc
-
 =head1 NAME
 
 Dist::Zilla::Plugin::MungeFile::WithConfigFile - Modify files in the build, with templates and config data from a file
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -135,10 +131,6 @@ And during the build, F<lib/My/Module.pm>:
 
     my $some_string = '{{ expensive_build_time_sub($config_data{some_field}) }}';
     my ${{ $house }} = 'my castle';
-    __DATA__
-    alpha
-    beta
-    gamma
 
 Is transformed to:
 
@@ -147,6 +139,8 @@ Is transformed to:
 
 =head1 DESCRIPTION
 
+=for stopwords FileMunger
+
 This is a L<FileMunger|Dist::Zilla::Role::FileMunger> plugin for
 L<Dist::Zilla> that passes a file(s)
 through a L<Text::Template>, with a variable provided that contains data
@@ -170,11 +164,9 @@ along in variables named for each key.
 
 =head1 OPTIONS
 
-=over 4
+=head2 C<finder>
 
-=item *
-
-C<finder>
+=for stopwords FileFinder
 
 This is the name of a L<FileFinder|Dist::Zilla::Role::FileFinder> for finding
 files to modify.
@@ -186,21 +178,28 @@ L<[FileFinder::ByName]|Dist::Zilla::Plugin::FileFinder::ByName> plugin.
 
 There is no default.
 
-=item * C<file>
+=head2 C<file>
 
 Indicates the filename in the dist to be operated upon; this file can exist on
 disk, or have been generated by some other plugin.  Can be included more than once.
 
 B<At least one of the C<finder> or C<file> options is required.>
 
-=item * C<arbitrary option>
+=head2 C<arbitrary option>
 
 All other keys/values provided will be passed to the template as is.
 
-=back
+=head1 CAVEATS
+
+Presently, the config file is not read with any sort of file decoding (e.g.
+UTF-8), so any extracted strings should be appropriately decoded first. This
+is an issue that needs to be resolved in L<Config::Any> (perhaps by having the
+caller, in our case L<MooseX::SimpleConfig>, to pass the desired decoding).
 
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MungeFile-WithConfigFile>
 (or L<bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
@@ -227,7 +226,7 @@ L<Dist::Zilla::Plugin::MungeFile::WithDataSection>
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
